include/filter/msfilter/svdfppt.hxx |    2 +-
 include/svl/zformat.hxx             |    6 +++---
 sc/source/filter/inc/tokstack.hxx   |    2 +-
 sc/source/ui/unoobj/scdetect.cxx    |    8 ++++----
 svx/source/svdraw/svdedtv2.cxx      |   12 ++++++------
 svx/source/svdraw/svdmark.cxx       |    4 ++--
 svx/source/svdraw/svdmrkv1.cxx      |    4 ++--
 svx/source/svdraw/svdoedge.cxx      |   34 +++++++++++++++++-----------------
 8 files changed, 36 insertions(+), 36 deletions(-)

New commits:
commit 4ab53b40329e9cf2a50dfb90bb559ace309b7263
Author:     Noel Grandin <noel.gran...@collabora.co.uk>
AuthorDate: Tue Mar 12 16:51:39 2019 +0200
Commit:     Noel Grandin <noel.gran...@collabora.co.uk>
CommitDate: Wed Mar 13 07:19:41 2019 +0100

    translate some german var names
    
    Anz -> Count
    
    Change-Id: I26f85cee2dff12377dbf0b21f8ad7b98d15b95c3
    Reviewed-on: https://gerrit.libreoffice.org/69103
    Tested-by: Jenkins
    Reviewed-by: Noel Grandin <noel.gran...@collabora.co.uk>

diff --git a/include/filter/msfilter/svdfppt.hxx 
b/include/filter/msfilter/svdfppt.hxx
index 78fbeecee368..f907cc01d40e 100644
--- a/include/filter/msfilter/svdfppt.hxx
+++ b/include/filter/msfilter/svdfppt.hxx
@@ -1085,7 +1085,7 @@ struct PPTStyleTextPropReader
                 PPTCharPropSet& aCharPropSet,
                 const OUString& aString,
                 sal_uInt32& nCharCount,
-                sal_uInt32 nCharAnzRead,
+                sal_uInt32 nCharReadCnt,
                 bool& bTextPropAtom,
                 sal_uInt32 nExtParaPos,
                 const std::vector< StyleTextProp9 >& aStyleTextProp9,
diff --git a/sc/source/filter/inc/tokstack.hxx 
b/sc/source/filter/inc/tokstack.hxx
index 31cc18518494..50d4bbd6f66f 100644
--- a/sc/source/filter/inc/tokstack.hxx
+++ b/sc/source/filter/inc/tokstack.hxx
@@ -201,7 +201,7 @@ private:
 
         std::unique_ptr<sal_uInt16[]>   pElement;   // Array with Indices for 
elements
         std::unique_ptr<E_TYPE[]>       pType;      // ...with Type-Info
-        std::unique_ptr<sal_uInt16[]>   pSize;      // ...with size (Anz. 
sal_uInt16)
+        std::unique_ptr<sal_uInt16[]>   pSize;      // ...with size
         sal_uInt16                      nElement;
         sal_uInt16                      nElementCurrent;
 
diff --git a/sc/source/ui/unoobj/scdetect.cxx b/sc/source/ui/unoobj/scdetect.cxx
index 23071a09ea7f..4f18e3b1d853 100644
--- a/sc/source/ui/unoobj/scdetect.cxx
+++ b/sc/source/ui/unoobj/scdetect.cxx
@@ -43,7 +43,7 @@ namespace {
 // 0x8000: recognition finished
 
 #define M_DC        0x0100
-#define M_ALT(ANZ)  (0x0200+(ANZ))
+#define M_ALT(CNT)  (0x0200+(CNT))
 #define M_ENDE      0x8000
 
 const sal_uInt16 pLotus[] =      // Lotus 1/1A/2
@@ -115,14 +115,14 @@ bool detectThisFormat(SvStream& rStr, const sal_uInt16* 
pSearch)
         }
         else if( nMuster & M_ALT(0) )
         { // alternative Bytes
-            sal_uInt8 nAnzAlt = static_cast<sal_uInt8>(nMuster);
+            sal_uInt8 nCntAlt = static_cast<sal_uInt8>(nMuster);
             bSync = false;          // first unsynchron
-            while( nAnzAlt > 0 )
+            while( nCntAlt > 0 )
             {
                 pSearch++;
                 if( static_cast<sal_uInt8>(*pSearch) == nByte )
                     bSync = true;   // only now synchronization
-                nAnzAlt--;
+                nCntAlt--;
             }
         }
         else if( nMuster & M_ENDE )
diff --git a/svx/source/svdraw/svdedtv2.cxx b/svx/source/svdraw/svdedtv2.cxx
index f9fd815444b5..7b503bf9c5df 100644
--- a/svx/source/svdraw/svdedtv2.cxx
+++ b/svx/source/svdraw/svdedtv2.cxx
@@ -2020,7 +2020,7 @@ void SdrEditView::DoImportMarkedMtf(SvdProgressInfo 
*pProgrInfo)
         SdrPageView* pPV=pM->GetPageView();
         SdrObjList*  pOL=pObj->getParentSdrObjListFromSdrObject();
         const size_t nInsPos=pObj->GetOrdNum()+1;
-        sal_uIntPtr        nInsAnz=0;
+        sal_uIntPtr      nInsCnt=0;
         tools::Rectangle aLogicRect;
 
         SdrGrafObj*  pGraf = dynamic_cast<SdrGrafObj*>( pObj );
@@ -2033,7 +2033,7 @@ void SdrEditView::DoImportMarkedMtf(SvdProgressInfo 
*pProgrInfo)
                 {
                     aLogicRect = pGraf->GetLogicRect();
                     ImpSdrGDIMetaFileImport aFilter(*mpModel, 
pObj->GetLayer(), aLogicRect);
-                    nInsAnz = aFilter.DoImport(aMetaFile, *pOL, nInsPos, 
pProgrInfo);
+                    nInsCnt = aFilter.DoImport(aMetaFile, *pOL, nInsPos, 
pProgrInfo);
                 }
             }
             else if (pGraf->isEmbeddedPdfData())
@@ -2043,7 +2043,7 @@ void SdrEditView::DoImportMarkedMtf(SvdProgressInfo 
*pProgrInfo)
                 ImpSdrPdfImport aFilter(*mpModel, pObj->GetLayer(), 
aLogicRect, pGraf->getEmbeddedPdfData());
                 if (pGraf->getEmbeddedPageNumber() < aFilter.GetPageCount())
                 {
-                    nInsAnz = aFilter.DoImport(*pOL, nInsPos, 
pGraf->getEmbeddedPageNumber(), pProgrInfo);
+                    nInsCnt = aFilter.DoImport(*pOL, nInsPos, 
pGraf->getEmbeddedPageNumber(), pProgrInfo);
                 }
 #endif // HAVE_FEATURE_PDFIUM
             }
@@ -2054,10 +2054,10 @@ void SdrEditView::DoImportMarkedMtf(SvdProgressInfo 
*pProgrInfo)
         {
             aLogicRect = pOle2->GetLogicRect();
             ImpSdrGDIMetaFileImport aFilter(*mpModel, pObj->GetLayer(), 
aLogicRect);
-            nInsAnz = aFilter.DoImport(pOle2->GetGraphic()->GetGDIMetaFile(), 
*pOL, nInsPos, pProgrInfo);
+            nInsCnt = aFilter.DoImport(pOle2->GetGraphic()->GetGDIMetaFile(), 
*pOL, nInsPos, pProgrInfo);
         }
 
-        if (nInsAnz != 0)
+        if (nInsCnt != 0)
         {
             // transformation
             GeoStat aGeoStat(pGraf ? pGraf->GetGeoStat() : 
pOle2->GetGeoStat());
@@ -2069,7 +2069,7 @@ void SdrEditView::DoImportMarkedMtf(SvdProgressInfo 
*pProgrInfo)
             if (aGeoStat.nRotationAngle)
                 aGeoStat.RecalcSinCos();
 
-            for (sal_uIntPtr i = 0; i < nInsAnz; i++)
+            for (sal_uIntPtr i = 0; i < nInsCnt; i++)
             {
                 if (bUndo)
                     
AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoNewObject(*pOL->GetObj(nObj)));
diff --git a/svx/source/svdraw/svdmark.cxx b/svx/source/svdraw/svdmark.cxx
index 812f57e67dca..47d055548b4d 100644
--- a/svx/source/svdraw/svdmark.cxx
+++ b/svx/source/svdraw/svdmark.cxx
@@ -752,9 +752,9 @@ namespace sdr
 
                         if(pBC)
                         {
-                            const size_t nLstAnz(pBC->GetSizeOfVector());
+                            const size_t nLstCnt(pBC->GetSizeOfVector());
 
-                            for(size_t nl=0; nl < nLstAnz; ++nl)
+                            for(size_t nl=0; nl < nLstCnt; ++nl)
                             {
                                 SfxListener* pLst = pBC->GetListener(nl);
                                 SdrEdgeObj* pEdge = dynamic_cast<SdrEdgeObj*>( 
pLst );
diff --git a/svx/source/svdraw/svdmrkv1.cxx b/svx/source/svdraw/svdmrkv1.cxx
index 34b24cdfff41..e11d8a5ebb9b 100644
--- a/svx/source/svdraw/svdmrkv1.cxx
+++ b/svx/source/svdraw/svdmrkv1.cxx
@@ -410,8 +410,8 @@ bool SdrMarkView::MarkGluePoints(const tools::Rectangle* 
pRect, bool bUnmark)
             }
         } else {
             if (pGPL!=nullptr) {
-                sal_uInt16 nGPAnz=pGPL->GetCount();
-                for (sal_uInt16 nGPNum=0; nGPNum<nGPAnz; nGPNum++) {
+                sal_uInt16 nGluePointCnt=pGPL->GetCount();
+                for (sal_uInt16 nGPNum=0; nGPNum<nGluePointCnt; nGPNum++) {
                     const SdrGluePoint& rGP=(*pGPL)[nGPNum];
 
                     // #i38892#
diff --git a/svx/source/svdraw/svdoedge.cxx b/svx/source/svdraw/svdoedge.cxx
index 2755d31167d0..1538caf3af4e 100644
--- a/svx/source/svdraw/svdoedge.cxx
+++ b/svx/source/svdraw/svdoedge.cxx
@@ -266,7 +266,7 @@ void SdrEdgeObj::ImpSetEdgeInfoToAttr()
 {
     const SfxItemSet& rSet = GetObjectItemSet();
     SdrEdgeKind eKind = rSet.Get(SDRATTR_EDGEKIND).GetValue();
-    sal_Int32 nValAnz = rSet.Get(SDRATTR_EDGELINEDELTACOUNT).GetValue();
+    sal_Int32 nValCnt = rSet.Get(SDRATTR_EDGELINEDELTACOUNT).GetValue();
     sal_Int32 nVal1 = rSet.Get(SDRATTR_EDGELINE1DELTA).GetValue();
     sal_Int32 nVal2 = rSet.Get(SDRATTR_EDGELINE2DELTA).GetValue();
     sal_Int32 nVal3 = rSet.Get(SDRATTR_EDGELINE3DELTA).GetValue();
@@ -315,10 +315,10 @@ void SdrEdgeObj::ImpSetEdgeInfoToAttr()
         nVals[1] = bHor2 ? aEdgeInfo.aObj2Line2.X() : aEdgeInfo.aObj2Line2.Y();
     }
 
-    if(n != nValAnz || nVals[0] != nVal1 || nVals[1] != nVal2 || nVals[2] != 
nVal3)
+    if(n != nValCnt || nVals[0] != nVal1 || nVals[1] != nVal2 || nVals[2] != 
nVal3)
     {
         // Here no more notifying is necessary, just local changes are OK.
-        if(n != nValAnz)
+        if(n != nValCnt)
         {
             GetProperties().SetObjectItemDirect(SdrEdgeLineDeltaCountItem(n));
         }
@@ -501,17 +501,17 @@ bool SdrEdgeObj::CheckNodeConnection(bool bTail1) const
     if(nullptr != rCon.pObj && rCon.pObj->getSdrPageFromSdrObject() == 
getSdrPageFromSdrObject() && 0 != nPointCount)
     {
         const SdrGluePointList* pGPL=rCon.pObj->GetGluePointList();
-        sal_uInt16 nConAnz=pGPL==nullptr ? 0 : pGPL->GetCount();
-        sal_uInt16 nGesAnz=nConAnz+8;
+        sal_uInt16 nGluePointCnt=pGPL==nullptr ? 0 : pGPL->GetCount();
+        sal_uInt16 nGesAnz=nGluePointCnt+8;
         Point aTail(bTail1 ? (*pEdgeTrack)[0] : 
(*pEdgeTrack)[sal_uInt16(nPointCount-1)]);
         for (sal_uInt16 i=0; i<nGesAnz && !bRet; i++) {
-            if (i<nConAnz) { // UserDefined
+            if (i<nGluePointCnt) { // UserDefined
                 bRet=aTail==(*pGPL)[i].GetAbsolutePos(*rCon.pObj);
-            } else if (i<nConAnz+4) { // Vertex
-                SdrGluePoint aPt(rCon.pObj->GetVertexGluePoint(i-nConAnz));
+            } else if (i<nGluePointCnt+4) { // Vertex
+                SdrGluePoint 
aPt(rCon.pObj->GetVertexGluePoint(i-nGluePointCnt));
                 bRet=aTail==aPt.GetAbsolutePos(*rCon.pObj);
             } else {                  // Corner
-                SdrGluePoint aPt(rCon.pObj->GetCornerGluePoint(i-nConAnz-4));
+                SdrGluePoint 
aPt(rCon.pObj->GetCornerGluePoint(i-nGluePointCnt-4));
                 bRet=aTail==aPt.GetAbsolutePos(*rCon.pObj);
             }
         }
@@ -2173,16 +2173,16 @@ bool SdrEdgeObj::ImpFindConnector(const Point& rPt, 
const SdrPageView& rPV, SdrO
                 // After those come Vertex, Corner and center (Best), all 
prioritized equally.
                 // Finally, a HitTest for the object.
                 const SdrGluePointList* pGPL=pObj->GetGluePointList();
-                sal_uInt16 nConAnz=pGPL==nullptr ? 0 : pGPL->GetCount();
-                sal_uInt16 nGesAnz=nConAnz+9;
+                sal_uInt16 nGluePointCnt=pGPL==nullptr ? 0 : pGPL->GetCount();
+                sal_uInt16 nGesAnz=nGluePointCnt+9;
                 bool bUserFnd = false;
                 sal_uIntPtr nBestDist=0xFFFFFFFF;
                 for (sal_uInt16 i=0; i<nGesAnz; i++)
                 {
-                    bool bUser=i<nConAnz;
-                    bool bVertex=i>=nConAnz+0 && i<nConAnz+4;
-                    bool bCorner=i>=nConAnz+4 && i<nConAnz+8;
-                    bool bCenter=i==nConAnz+8;
+                    bool bUser=i<nGluePointCnt;
+                    bool bVertex=i>=nGluePointCnt+0 && i<nGluePointCnt+4;
+                    bool bCorner=i>=nGluePointCnt+4 && i<nGluePointCnt+8;
+                    bool bCenter=i==nGluePointCnt+8;
                     bool bOk = false;
                     Point aConPos;
                     sal_uInt16 nConNum=i;
@@ -2192,12 +2192,12 @@ bool SdrEdgeObj::ImpFindConnector(const Point& rPt, 
const SdrPageView& rPV, SdrO
                         nConNum=rGP.GetId();
                         bOk = true;
                     } else if (bVertex && !bUserFnd) {
-                        nConNum=nConNum-nConAnz;
+                        nConNum=nConNum-nGluePointCnt;
                         SdrGluePoint aPt(pObj->GetVertexGluePoint(nConNum));
                         aConPos=aPt.GetAbsolutePos(*pObj);
                         bOk = true;
                     } else if (bCorner && !bUserFnd) {
-                        nConNum-=nConAnz+4;
+                        nConNum-=nGluePointCnt+4;
                         i+=3;
                     }
                     else if (bCenter && !bUserFnd && !bEdge)
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/include/svl/zformat.hxx b/include/svl/zformat.hxx
index a9434979a1f8..55a3d3c6f76c 100644
--- a/include/svl/zformat.hxx
+++ b/include/svl/zformat.hxx
@@ -57,7 +57,7 @@ struct ImpSvNumberformatInfo            // Struct for 
FormatInfo
     SvNumFormatType eScannedType;       // Type determined by scan
     bool bThousand;                     // Has group (AKA thousand) separator
 
-    void Copy( const ImpSvNumberformatInfo& rNumFor, sal_uInt16 nAnz );
+    void Copy( const ImpSvNumberformatInfo& rNumFor, sal_uInt16 nCount );
 };
 
 // NativeNumber, represent numbers using CJK or other digits if nNum>0,
@@ -103,7 +103,7 @@ public:
     ImpSvNumFor();                      // Ctor without filling the Info
     ~ImpSvNumFor();
 
-    void Enlarge(sal_uInt16 nAnz);      // Init of arrays to the right size
+    void Enlarge(sal_uInt16 nCount);    // Init of arrays to the right size
 
     // if pSc is set, it is used to get the Color pointer
     void Copy( const ImpSvNumFor& rNumFor, ImpSvNumberformatScan* pSc );
@@ -310,7 +310,7 @@ public:
                 // First try a simple approach. Note that this is called only
                 // if all MidStrings did match so far, to verify that all
                 // strings of the format were matched and not just the starting
                 // sequence, so we don't have to check if GetnAnz() includes
                 // [modifiers] or anything else if both counts are equal.
                 sal_uInt16 nCnt = NumFor[nNumFor].GetCount();
                 if ( nAllCount == nCnt )
@@ -310,7 +310,7 @@ public:
                 // if all MidStrings did match so far, to verify that all
                 // strings of the format were matched and not just the starting
-                // sequence, so we don't have to check if GetnAnz() includes
+                // sequence, so we don't have to check if GetCount() includes
                 // [modifiers] or anything else if both counts are equal.
                 sal_uInt16 nCnt = NumFor[nNumFor].GetCount();